# Github Light Colorblind

This style mimics the github light colorblind theme from vscode themes.

![Screenshot of the github-light-colorblind theme in a bash script](./images/github-light-colorblind.png)

## Colors

Background color: ![#ffffff](https://via.placeholder.com/20/ffffff/ffffff.png) `#ffffff`

Highlight color: ![#0969da4a](https://via.placeholder.com/20/0969da4a/0969da4a.png) `#0969da4a`

**WCAG compliance**

| Color                                             | Hex       | Ratio    | Normal text | Large text |
| ------------------------------------------------- | --------- | -------- | ----------- | ---------- |
| ![#6e7781](../../a11y_pygments/assets/6e7781.png) | `#6e7781` | 4.5 : 1  | AA          | AAA        |
| ![#b35900](../../a11y_pygments/assets/b35900.png) | `#b35900` | 4.8 : 1  | AA          | AAA        |
| ![#8a4600](../../a11y_pygments/assets/8a4600.png) | `#8a4600` | 7.1 : 1  | AAA         | AAA        |
| ![#0550ae](../../a11y_pygments/assets/0550ae.png) | `#0550ae` | 7.6 : 1  | AAA         | AAA        |
| ![#8250df](../../a11y_pygments/assets/8250df.png) | `#8250df` | 5.0 : 1  | AA          | AAA        |
| ![#24292f](../../a11y_pygments/assets/24292f.png) | `#24292f` | 14.7 : 1 | AAA         | AAA        |
